summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorOliver Tappe2008-03-24 12:00:05 +0100
committerOliver Tappe2008-03-24 12:00:05 +0100
commit1c1afb3e2a397eb906ff0b2884cadf2eb5e4fc02 (patch)
tree1227b49d779e1784f42a9681baebcb88605d6fdf
parent* Adjusted OSSetup::Distro implementations to apply necessary fixes as part o... (diff)
downloadcore-1c1afb3e2a397eb906ff0b2884cadf2eb5e4fc02.tar.gz
core-1c1afb3e2a397eb906ff0b2884cadf2eb5e4fc02.tar.xz
core-1c1afb3e2a397eb906ff0b2884cadf2eb5e4fc02.zip
* renamed 'bootlog' plugin to 'syslog', as that is what it is going to become, soon
git-svn-id: http://svn.openslx.org/svn/openslx/openslx/trunk@1680 95ad53e4-c205-0410-b2fa-d234c58c8868
-rw-r--r--os-plugins/plugins/syslog/OpenSLX/OSPlugin/syslog.pm (renamed from os-plugins/plugins/bootlog/OpenSLX/OSPlugin/bootlog.pm)18
-rw-r--r--os-plugins/plugins/syslog/init-hooks/15-have-ip-config/syslog.sh (renamed from os-plugins/plugins/bootlog/init-hooks/15-have-ip-config/bootlog.sh)0
2 files changed, 9 insertions, 9 deletions
diff --git a/os-plugins/plugins/bootlog/init-hooks/15-have-ip-config/bootlog.sh b/os-plugins/plugins/syslog/init-hooks/15-have-ip-config/syslog.sh
index a1a07e8a..a1a07e8a 100644
--- a/os-plugins/plugins/bootlog/init-hooks/15-have-ip-config/bootlog.sh
+++ b/os-plugins/plugins/syslog/init-hooks/15-have-ip-config/syslog.sh
diff --git a/os-plugins/plugins/bootlog/OpenSLX/OSPlugin/bootlog.pm b/os-plugins/plugins/syslog/OpenSLX/OSPlugin/syslog.pm
index fab0be95..5ded36ee 100644
--- a/os-plugins/plugins/bootlog/OpenSLX/OSPlugin/bootlog.pm
+++ b/os-plugins/plugins/syslog/OpenSLX/OSPlugin/syslog.pm
@@ -8,11 +8,11 @@
#
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
# bootlog.pm
# - implementation of the 'bootlog' plugin, which installs
# all needed information for a displaymanager and for the bootlog.
# -----------------------------------------------------------------------------
-package OpenSLX::OSPlugin::bootlog;
+package OpenSLX::OSPlugin::syslog;
use strict;
use warnings;
@@ -30,7 +30,7 @@ sub new
my $class = shift;
my $self = {
- name => 'bootlog',
+ name => 'syslog',
};
return bless $self, $class;
@@ -53,21 +53,21 @@ sub getAttrInfo
my $self = shift;
return {
- 'bootlog::active' => {
+ 'syslog::active' => {
applies_to_systems => 1,
applies_to_clients => 1,
description => unshiftHereDoc(<<' End-of-Here'),
- should the 'bootlog'-plugin be executed during boot?
+ should the 'syslog'-plugin be executed during boot?
End-of-Here
content_regex => qr{^(0|1)$},
content_descr => '1 means active - 0 means inactive',
default => '1',
},
- 'bootlog::target' => {
+ 'syslog::target' => {
applies_to_systems => 1,
applies_to_clients => 1,
description => unshiftHereDoc(<<' End-of-Here'),
- ip:port where bootlog shall be sent to
+ ip:port where syslog shall be sent to
End-of-Here
content_regex => undef,
content_descr => 'allowed: gdm, kdm, xdm',
@@ -8,11 +8,11 @@
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
-# bootlog.pm
-# - implementation of the 'bootlog' plugin, which installs
-# all needed information for a displaymanager and for the bootlog.
+# syslog.pm
+# - implementation of the 'syslog' plugin, which installs
+# all needed information for a displaymanager and for the syslog.
# -----------------------------------------------------------------------------